==> nextcloud-29.0.7.tar.bz2: nextcloud/apps/files_external/l10n/uk.js <==
OC.L10N.register(
    "files_external",
    {
    "Grant access" : "Дозволити доступ",
    "Error configuring OAuth1" : "Помилка з конфігуруванням OAuth1",
    "Please provide a valid app key and secret." : "Будь ласка, надайте дійсний ключ застосунку та пароль.",
    "Error configuring OAuth2" : "Помилка налаштування OAuth2",
    "Generate keys" : "Створити ключі",
    "Error generating key pair" : "Помилка створення ключової пари",
    "Type to select account or group." : "Обліковий запис або група.",
    "(Group)" : "(група)",
    "Compatibility with Mac NFD encoding (slow)" : "Сумісність із кодуванням Mac NFD (повільно)",
    "Enable encryption" : "Увімкнути шифрування",
    "Enable previews" : "Увімкнути попередній перегляд",
    "Enable sharing" : "Увімкнути спільний доступ",
    "Check for changes" : "Перевірити на зміни",
    "Never" : "Ніколи",
    "Once every direct access" : "Один раз при кожному прямому доступі",
    "Read only" : "Тільки читання",
    "Disconnect" : "Від'єднати",
    "Admin defined" : "Визначено адміністратором",
    "Automatic status checking is disabled due to the large number of configured storages, click to check status" : "Автоматична перевірка статусу вимкнена через велику кількість налаштованих сховищ, натисніть, щоб перевірити статус",
    "Are you sure you want to disconnect this external storage? It will make the storage unavailable in Nextcloud and will lead to a deletion of these files and folders on any sync client that is currently connected but will not delete any files and folders on the external storage itself." : "Ви впевнені, що бажаєте від’єднати це зовнішнє сховище? Це призведе до того, що сховище стане недоступним у хмарі Nextcloud, а також вилучить файли та каталоги на клієнтських пристроях, які наразі синхронізуються з хмарою. Файли та каталоги у зовнішньому сховищі не буде вилучено.",
    "Delete storage?" : "Вилучити сховище?",
    "Click to recheck the configuration" : "Клацніть для повторної перевірки налаштувань",
    "Saved" : "Збережено",
    "Saving …" : "Збереження …",
    "Save" : "Зберегти",
    "Forbidden to manage local mounts" : "Заборонено керувати місцевими кріпленнями",
    "Storage with ID \"%d\" not found" : "Сховище з ідентифікатором \"%d\" не знайдено",
    "Invalid backend or authentication mechanism class" : "Недійсний бекенд серверу або клас методу авторизації",
    "Invalid mount point" : "Невірна точка монтування",
    "Objectstore forbidden" : "Objectstore заборонено",
    "Invalid storage backend \"%s\"" : "Невірне сховище \"%s\"",
    "Not permitted to use backend \"%s\"" : "Не дозволено використовувати бекенд \"%s\"",
    "Not permitted to use authentication mechanism \"%s\"" : "Не дозволено використовувати метод авторизації \"%s\"",
    "Unsatisfied backend parameters" : "Незадоволені параметри серверної частини",
    "Unsatisfied authentication mechanism parameters" : "Умови методу авторизації не виконано",
    "Insufficient data: %s" : "Недостатні дані: %s",
    "%s" : "%s ",
    "Storage with ID \"%d\" is not editable by non-admins" : "Дані сховища ID \"%d\" можуть редагувати тільки адміністратори",
    "Access key" : "Ключ доступу",
    "Secret key" : "Пароль",
    "Builtin" : "Вбудовано",
    "None" : "Жоден",
    "OAuth1" : "OAuth1",
    "App key" : "Ключ застосунку",
    "App secret" : "Секретний ключ застосунку",
    "OAuth2" : "OAuth2",
    "Client ID" : "Ідентифікатор клієнта",
    "Client secret" : "Ключ клієнта",
    "OpenStack v2" : "OpenStack v2",
    "Login" : "Вхід",
    "Password" : "Пароль",
    "Tenant name" : "Ім'я орендаря",
    "Identity endpoint URL" : "URL кінцевої точки ідентифікації",
    "OpenStack v3" : "OpenStack v3",
    "Domain" : "Домен",
    "Rackspace" : "Rackspace",
    "API key" : "ключ API",
    "Global credentials" : "Системні дані авторизації",
    "Log-in credentials, save in database" : "Дані авторизації у системі, зберегти у базі даних",
    "Login and password" : "Лоґін та пароль",
    "Log-in credentials, save in session" : "Дані авторизації у системі, зберегти у сесії",
    "Global credentials, manually entered" : "Глобальні дані авторизації, які зазначено вручну",
    "Manually entered, store in database" : "Зазначені вручну, зберігаються у базі даних",
    "RSA public key" : "Відкритий ключ RSA",
    "Public key" : "Відкритий ключ",
    "RSA private key" : "Закритий ключ RSA",
    "Private key" : "Приватний ключ",
    "Kerberos default realm, defaults to \"WORKGROUP\"" : "Сфера за замовчуванням Kerberos, за замовчуванням \"WORKGROUP\"",
    "Kerberos ticket Apache mode" : "Квиток Kerberos Режим ApacheКвиток Kerberos Режим Apache",
    "Kerberos ticket" : "Квиток Kerberos",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Кошик",
    "Hostname" : "Ім'я хоста",
    "Port" : "Порт",
    "Region" : "Регіон",
    "Storage Class" : "Клас сховища",
    "Enable SSL" : "Включити SSL",
    "Enable Path Style" : "Включити стиль шляху",
    "Legacy (v2) authentication" : "Застарілий метод авторизації (v2) ",
    "Enable multipart copy" : "Дозволити множинне копіювання",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "Віддалений підкаталог",
    "Secure https://" : "Захищений https://",
    "FTP" : "FTP",
    "Host" : "Хост",
    "Secure ftps://" : "Захищений ftps://",
    "Local" : "Локально",
    "Location" : "Місце",
    "Nextcloud" : "Nextcloud",
    "SFTP" : "SFTP",
    "Root" : "Початок",
    "SFTP with secret key login" : "SFTP із секретним ключем входу",
    "SMB/CIFS" : "SMB/CIFS",
    "Share" : "Спільний доступ",
    "Show hidden files" : "Показати приховані файли",
    "Case sensitive file system" : "Файлова система, чутлива до регістру символів",
    "Disabling it will allow to use a case insensitive file system, but comes with a performance penalty" : "Вимкнення цього параметра дозволить використовувати файлову систему, нечутливу до регістру, але це також призведе до зниження продуктивності",
    "Verify ACL access when listing files" : "Перевірте доступ до ACL під час переліку файлів",
    "Timeout" : "Час вичерпано",
    "SMB/CIFS using OC login" : "SMB/CIFS з використанням входу OC",
    "Login as share" : "Увійти під спільним доступом",
    "OpenStack Object Storage" : "OpenStack Object Storage",
    "Service name" : "Назва служби",
    "Request timeout (seconds)" : "Час очікування запиту (секунди)",
    "The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "Підтримку cURL у PHP не ввімкнено або не встановлено. Монтаж %s неможливий. Будь ласка, попросіть свого системного адміністратора встановити його.",
    "The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "Підтримку FTP у PHP не увімкнено або не встановлено. Під'єднання%s неможлие. Будь ласка, попросіть вашого системного адміністратора зробити відповідні налаштування.",
    "\"%1$s\" is not installed. Mounting of %2$s is not possible. Please ask your system administrator to install it." : "\"%1$s\" не встановлено. Монтаж %2$s неможливий. Будь ласка, попросіть свого системного адміністратора встановити його.",
    "External storage" : "Зовнішнє сховище",
    "External storage support" : "Підтримка зовнішнього сховища",
    "Adds basic external storage support" : "Додає базову підтримку зовнішньої пам’яті",
    "Enter missing credentials" : "Зазначте відсутні дані авторизації",
    "Unable to update this external storage config. {statusMessage}" : "Не вдалося оновити конфігурацію цього зовнішнього сховища. {statusMessage}",
    "New configuration successfully saved" : "Нову конфігурацію успішно збережено",
    "There was an error with this external storage." : "З цим зовнішнім сховищем виникла помилка.",
    "We were unable to check the external storage {basename}" : "Нам не вдалося перевірити зовнішнє сховище {basename}",
    "Examine this faulty external storage configuration" : "Перевірте цю несправну конфігурацію зовнішнього сховища",
    "Open in Files" : "Відкрити у Файлах",
    "There was an error with this external storage. Do you want to review this mount point config in the settings page?" : "Виникла помилка із зовнішнім сховищем. Бажаєте переглянути конфігурацію точки монтування на сторінці налаштувань?",
    "External mount error" : "Помилка з приєднанням зовнішнього ресурсу",
    "List of external storage." : "Перелік вмісту зовнішнього сховища.",
    "There is no external storage configured. You can configure them in your Personal settings." : "Відсутні налаштовані зовнішні сховища. Ви можете налаштувати їх в особистих налаштуваннях.",
    "There is no external storage configured and you don't have the permission to configure them." : "Відсутні налаштовані зовнішні сховища, і у вас немає дозволу на їх налаштування.",
    "No external storage" : "Відсутні зовнішні сховища",
    "Storage type" : "Тип сховища",
    "Unknown" : "Невідомо",
    "Scope" : "Область",
    "Personal" : "Особисте",
    "System" : "Система",
    "No external storage configured or you don't have the permission to configure them" : "Зовнішнє сховище не налаштовано або ви не маєте дозволу на їх налаштування",
    "Open documentation" : "Відкрити документацію",
    "Folder name" : "Назва каталогу",
    "Authentication" : "Авторизація",
    "Configuration" : "Налаштування",
    "Available for" : "Доступний для",
    "Add storage" : "Додати сховище",
    "All people" : "Всі користувачі",
    "Advanced settings" : "Розширені",
    "Allow people to mount external storage" : "Дозволити користувачам під'єднувати зовнішні сховища даних",
    "Global credentials can be used to authenticate with multiple external storages that have the same credentials." : "Універсальні облікові дані можна використовувати для авторизації з кількома зовнішніми сховищами, які мають тотодні облікові дані.",
    "Type to select user or group." : "Почніть друкувати, щоб вибрати користувача або групу.",
    "Storage with ID \"%d\" is not user editable" : "У користувачів відсутній доступ на запис до сховища з ідентифікатором \"%d\"",
    "Username" : "Ім'я користувача",
    "Username and password" : "Ім'я користувача та пароль",
    "Global credentials, user entered" : "Системні дані авторизації, зазначені користувачем",
    "User entered, store in database" : "Зазначено користувачем, зберегти у базі даних",
    "Check the ACL's of each file or folder inside a directory to filter out items where the user has no read permissions, comes with a performance penalty" : "Перевірка ACL кожного файлу чи каталогу у каталозі верхнього рівня, щоб відфільтрувати елементи, до яких користувач не має прав доступу на читання, супроводжується погіршенням продуктивності",
    "Username as share" : "Ім'я для відкритого доступу",
    "This application enables administrators to configure connections to external storage providers, such as FTP servers, S3 or SWIFT object stores, other Nextcloud servers, WebDAV servers, and more. Administrators can choose which types of storage to enable and can mount these storage locations for a user, a group, or the entire system. Users will see a new folder appear in their root Nextcloud directory, which they can access and use like any other Nextcloud folder. External storage also allows users to share files stored in these external locations. In these cases, the credentials for the owner of the file are used when the recipient requests the file from external storage, thereby ensuring that the recipient can access the shared file.\n\nExternal storage can be configured using the GUI or at the command line. This second option provides the advanced user with more flexibility for configuring bulk external storage mounts and setting mount priorities. More information is available in the external storage GUI documentation and the external storage Configuration File documentation." : "Цей застосунок дозволяє адміністраторам налаштовувати підключення до зовнішніх постачальників сховищ, таких як сервери FTP, сховища об’єктів S3 або SWIFT, інші сервери Nextcloud, сервери WebDAV тощо. Адміністратори можуть вибрати, які типи сховищ увімкнути, і можуть монтувати ці місця зберігання для користувача, групи або всієї системи. Користувачі побачать новий каталог, яка з’явиться в кореневому каталозі Nextcloud, до якої вони зможуть отримати доступ і використовувати як будь-який інший каталог Nextcloud. Зовнішнє сховище також дозволяє користувачам ділитися файлами, що зберігаються в цих зовнішніх місцях. У цих випадках облікові дані для власника файлу використовуються, коли одержувач запитує файл із зовнішнього сховища, таким чином гарантуючи, що одержувач може отримати доступ до спільного файлу. \n\nЗовнішнє сховище можна налаштувати за допомогою графічного інтерфейсу користувача або в командному рядку. Цей другий параметр надає досвідченому користувачеві більшу гнучкість у налаштуванні масових підключень зовнішніх накопичувачів і встановлення пріоритетів підключення. Більше інформації доступно в документація графічного інтерфейсу зовнішнього сховища та документація файлу конфігурації зовнішнього сховища.",
    "External storage enables you to mount external storage services and devices as secondary Nextcloud storage devices. You may also allow users to mount their own external storage services." : "Зовнішня пам’ять дає змогу підключати зовнішні служби зберігання та пристрої як додаткові пристрої зберігання даних Nextcloud. Ви також можете дозволити користувачам монтувати власні зовнішні служби зберігання.",
    "All users" : "Всі користувачі",
    "Allow users to mount external storage" : "Дозволити користувачам монтувати зовнішні сховища"
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");

==> nextcloud-29.0.14.tar.bz2: nextcloud/apps/files_external/l10n/uk.js <==
OC.L10N.register(
    "files_external",
    {
    "Grant access" : "Дозволити доступ",
    "Error configuring OAuth1" : "Помилка з конфігуруванням OAuth1",
    "Please provide a valid app key and secret." : "Будь ласка, надайте дійсний ключ застосунку та пароль.",
    "Error configuring OAuth2" : "Помилка налаштування OAuth2",
    "Generate keys" : "Створити ключі",
    "Error generating key pair" : "Помилка створення ключової пари",
    "Forbidden to manage local mounts" : "Заборонено керувати місцевими кріпленнями",
    "Storage with ID \"%d\" not found" : "Сховище з ідентифікатором \"%d\" не знайдено",
    "Invalid backend or authentication mechanism class" : "Недійсний бекенд серверу або клас методу авторизації",
    "Invalid mount point" : "Невірна точка монтування",
    "Objectstore forbidden" : "Objectstore заборонено",
    "Invalid storage backend \"%s\"" : "Невірне сховище \"%s\"",
    "Not permitted to use backend \"%s\"" : "Не дозволено використовувати бекенд \"%s\"",
    "Not permitted to use authentication mechanism \"%s\"" : "Не дозволено використовувати метод авторизації \"%s\"",
    "Unsatisfied backend parameters" : "Незадоволені параметри серверної частини",
    "Unsatisfied authentication mechanism parameters" : "Умови методу авторизації не виконано",
    "Insufficient data: %s" : "Недостатні дані: %s",
    "%s" : "%s ",
    "Storage with ID \"%d\" is not editable by non-admins" : "Дані сховища ID \"%d\" можуть редагувати тільки адміністратори",
    "Access key" : "Ключ доступу",
    "Secret key" : "Пароль",
    "Builtin" : "Вбудовано",
    "None" : "Жоден",
    "OAuth1" : "OAuth1",
    "App key" : "Ключ застосунку",
    "App secret" : "Секретний ключ застосунку",
    "OAuth2" : "OAuth2",
    "Client ID" : "Ідентифікатор клієнта",
    "Client secret" : "Ключ клієнта",
    "OpenStack v2" : "OpenStack v2",
    "Login" : "Вхід",
    "Password" : "Пароль",
    "Tenant name" : "Ім'я орендаря",
    "Identity endpoint URL" : "URL кінцевої точки ідентифікації",
    "OpenStack v3" : "OpenStack v3",
    "Domain" : "Домен",
    "Rackspace" : "Rackspace",
    "API key" : "ключ API",
    "Global credentials" : "Системні дані авторизації",
    "Log-in credentials, save in database" : "Дані авторизації у системі, зберегти у базі даних",
    "Login and password" : "Лоґін та пароль",
    "Log-in credentials, save in session" : "Дані авторизації у системі, зберегти у сесії",
    "Global credentials, manually entered" : "Глобальні дані авторизації, які зазначено вручну",
    "Manually entered, store in database" : "Зазначені вручну, зберігаються у базі даних",
    "RSA public key" : "Відкритий ключ RSA",
    "Public key" : "Відкритий ключ",
    "RSA private key" : "Закритий ключ RSA",
    "Private key" : "Приватний ключ",
    "Kerberos default realm, defaults to \"WORKGROUP\"" : "Сфера за замовчуванням Kerberos, за замовчуванням \"WORKGROUP\"",
    "Kerberos ticket Apache mode" : "Квиток Kerberos Режим ApacheКвиток Kerberos Режим Apache",
    "Kerberos ticket" : "Квиток Kerberos",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Кошик",
    "Hostname" : "Ім'я хоста",
    "Port" : "Порт",
    "Region" : "Регіон",
    "Storage Class" : "Клас сховища",
    "Enable SSL" : "Включити SSL",
    "Enable Path Style" : "Включити стиль шляху",
    "Legacy (v2) authentication" : "Застарілий метод авторизації (v2) ",
    "Enable multipart copy" : "Дозволити множинне копіювання",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "Віддалений підкаталог",
    "Secure https://" : "Захищений https://",
    "FTP" : "FTP",
    "Host" : "Хост",
    "Secure ftps://" : "Захищений ftps://",
    "Local" : "Локально",
    "Location" : "Місце",
    "Nextcloud" : "Nextcloud",
    "SFTP" : "SFTP",
    "Root" : "Початок",
    "SFTP with secret key login" : "SFTP із секретним ключем входу",
    "SMB/CIFS" : "SMB/CIFS",
    "Share" : "Спільний доступ",
    "Show hidden files" : "Показати приховані файли",
    "Case sensitive file system" : "Файлова система, чутлива до регістру символів",
    "Disabling it will allow to use a case insensitive file system, but comes with a performance penalty" : "Вимкнення цього параметра дозволить використовувати файлову систему, нечутливу до регістру, але це також призведе до зниження продуктивності",
    "Verify ACL access when listing files" : "Перевірте доступ до ACL під час переліку файлів",
    "Timeout" : "Час вичерпано",
    "SMB/CIFS using OC login" : "SMB/CIFS з використанням входу OC",
    "Login as share" : "Увійти під спільним доступом",
    "OpenStack Object Storage" : "OpenStack Object Storage",
    "Service name" : "Назва служби",
    "Request timeout (seconds)" : "Час очікування запиту (секунди)",
    "The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "Підтримку cURL у PHP не ввімкнено або не встановлено. Монтаж %s неможливий. Будь ласка, попросіть свого системного адміністратора встановити його.",
    "The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "Підтримку FTP у PHP не увімкнено або не встановлено. Під'єднання%s неможлие. Будь ласка, попросіть вашого системного адміністратора зробити відповідні налаштування.",
    "\"%1$s\" is not installed. Mounting of %2$s is not possible. Please ask your system administrator to install it." : "\"%1$s\" не встановлено. Монтаж %2$s неможливий. Будь ласка, попросіть свого системного адміністратора встановити його.",
    "External storage" : "Зовнішнє сховище",
    "External storage support" : "Підтримка зовнішнього сховища",
    "Adds basic external storage support" : "Додає базову підтримку зовнішньої пам’яті",
    "Confirm" : "Підтвердити",
    "Unable to update this external storage config. {statusMessage}" : "Не вдалося оновити конфігурацію цього зовнішнього сховища. {statusMessage}",
    "New configuration successfully saved" : "Нову конфігурацію успішно збережено",
    "Enter missing credentials" : "Зазначте відсутні дані авторизації",
    "There was an error with this external storage." : "З цим зовнішнім сховищем виникла помилка.",
    "We were unable to check the external storage {basename}" : "Нам не вдалося перевірити зовнішнє сховище {basename}",
    "Examine this faulty external storage configuration" : "Перевірте цю несправну конфігурацію зовнішнього сховища",
    "Open in Files" : "Відкрити у Файлах",
    "There was an error with this external storage. Do you want to review this mount point config in the settings page?" : "Виникла помилка із зовнішнім сховищем. Бажаєте переглянути конфігурацію точки монтування на сторінці налаштувань?",
    "External mount error" : "Помилка з приєднанням зовнішнього ресурсу",
    "List of external storage." : "Перелік вмісту зовнішнього сховища.",
    "There is no external storage configured. You can configure them in your Personal settings." : "Відсутні налаштовані зовнішні сховища. Ви можете налаштувати їх в особистих налаштуваннях.",
    "There is no external storage configured and you don't have the permission to configure them." : "Відсутні налаштовані зовнішні сховища, і у вас немає дозволу на їх налаштування.",
    "No external storage" : "Відсутні зовнішні сховища",
    "Storage type" : "Тип сховища",
    "Unknown" : "Невідомо",
    "Scope" : "Область",
    "Personal" : "Особисте",
    "System" : "Система",
    "Type to select account or group." : "Обліковий запис або група.",
    "(Group)" : "(група)",
    "Compatibility with Mac NFD encoding (slow)" : "Сумісність із кодуванням Mac NFD (повільно)",
    "Enable encryption" : "Увімкнути шифрування",
    "Enable previews" : "Увімкнути попередній перегляд",
    "Enable sharing" : "Увімкнути спільний доступ",
    "Check for changes" : "Перевірити на зміни",
    "Never" : "Ніколи",
    "Once every direct access" : "Один раз при кожному прямому доступі",
    "Read only" : "Тільки читання",
    "Disconnect" : "Від'єднати",
    "Admin defined" : "Визначено адміністратором",
    "Automatic status checking is disabled due to the large number of configured storages, click to check status" : "Автоматична перевірка статусу вимкнена через велику кількість налаштованих сховищ, натисніть, щоб перевірити статус",
    "Are you sure you want to disconnect this external storage? It will make the storage unavailable in Nextcloud and will lead to a deletion of these files and folders on any sync client that is currently connected but will not delete any files and folders on the external storage itself." : "Ви впевнені, що бажаєте від’єднати це зовнішнє сховище? Це призведе до того, що сховище стане недоступним у хмарі Nextcloud, а також вилучить файли та каталоги на клієнтських пристроях, які наразі синхронізуються з хмарою. Файли та каталоги у зовнішньому сховищі не буде вилучено.",
    "Delete storage?" : "Вилучити сховище?",
    "Click to recheck the configuration" : "Клацніть для повторної перевірки налаштувань",
    "Saved" : "Збережено",
    "Saving …" : "Збереження …",
    "Save" : "Зберегти",
    "No external storage configured or you don't have the permission to configure them" : "Зовнішнє сховище не налаштовано або ви не маєте дозволу на їх налаштування",
    "Open documentation" : "Відкрити документацію",
    "Folder name" : "Назва каталогу",
    "Authentication" : "Авторизація",
    "Configuration" : "Налаштування",
    "Available for" : "Доступний для",
    "Add storage" : "Додати сховище",
    "All people" : "Всі користувачі",
    "Advanced settings" : "Розширені",
    "Allow people to mount external storage" : "Дозволити користувачам під'єднувати зовнішні сховища даних",
    "Global credentials can be used to authenticate with multiple external storages that have the same credentials." : "Універсальні облікові дані можна використовувати для авторизації з кількома зовнішніми сховищами, які мають тотодні облікові дані."
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
